package ch.hslu.swk.g03.logger.common;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectInputStream;
import java.io.ObjectOutput;
import java.io.ObjectOutputStream;

public class ConverterUtils {

	/**
	 * Serializes an object
	 * 
	 * @param arg0
	 *            The object to serialize
	 * @return Returns a byte array on success, otherwise it returns null
	 * @throws IOException
	 */
	public static byte[] serialize(Object arg0) throws IOException {

		ByteArrayOutputStream stream = new ByteArrayOutputStream();
		ObjectOutput output = null;

		try {
			// Convert the object into a byte array
			output = new ObjectOutputStream(stream);
			output.writeObject(arg0);

			return stream.toByteArray();
		} finally {
			output.close();
			stream.close();
		}
	}

	/**
	 * Deserializes a byte array into a java class
	 * 
	 * @param data
	 *            The byte array of the serialized class
	 * @return Returns a java class on success, otherwise it returns null
	 * @throws IOException
	 * @throws ClassNotFoundException
	 */
	public static Object deserialize(byte[] data) throws IOException,
			ClassNotFoundException {

		ByteArrayInputStream stream = new ByteArrayInputStream(data);
		ObjectInput input = null;

		try {
			input = new ObjectInputStream(stream);

			return input.readObject();
		} finally {

			if (input != null) {
				input.close();
			}

			if (stream != null) {
				stream.close();
			}
		}
	}

	/**
	 * Converts a byte array into an integer
	 * @param b The byte array
	 * @return Returns an integer
	 */
	public static int byteArrayToInt(byte[] b) 
	{
	    int value = 0;
	    for (int i = 0; i < 4; i++) {
	        int shift = (4 - 1 - i) * 8;
	        value += (b[i] & 0x000000FF) << shift;
	    }
	    return value;
	}
}
