package ch.hslu.swk.g03.logger.common;

import java.text.SimpleDateFormat;
import java.util.Date;

import ch.hslu.loggerinterface.Loglevel;

public class LogMessage implements java.io.Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private static int autoId = 0;
	private int id = 0;
	private Date timestamp = new Date();
	private Loglevel loglevel = Loglevel.DEBUG;
	private String source = "";
	private String message = "";
	private String computer = "";

	public LogMessage() {
		// Prevent from overflow
		autoId = autoId + 1 % (Integer.MAX_VALUE - 1);

		id = autoId;
	}

	public LogMessage(String Message) {

		// Call main constructor
		this();

		setMessage(Message);
	}

	public LogMessage(String message, Loglevel level) {

		// Call main constructor
		this();

		setMessage(message);
		setLoglevel(level);
	}

	public LogMessage(String message, Loglevel level, String source) {

		// Call main constructor
		this();

		setMessage(message);
		setLoglevel(level);
		setSource(source);
	}

	public LogMessage(String message, Loglevel level, String source,
			String computer) {

		// Call main constructor
		this();

		setMessage(message);
		setLoglevel(level);
		setSource(source);
		setComputer(computer);
	}

	public int getId() {
		return id;
	}

	public Date getTimestamp() {
		return timestamp;
	}

	public void setTimestamp(Date timestamp) {
		this.timestamp = timestamp;
	}

	public Loglevel getLoglevel() {
		return loglevel;
	}

	public void setLoglevel(Loglevel loglevel) {
		this.loglevel = loglevel;
	}

	public String getSource() {
		return source;
	}

	public void setSource(String source) {
		this.source = source;
	}

	public String getMessage() {
		return message;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public String getComputer() {
		return computer;
	}

	public void setComputer(String computer) {
		this.computer = computer;
	}

	/**
	 * Returns Message as a string (CSV compliant). Format:
	 * ID,Timestamp,Loglevel,Computer,Source,Message
	 * 
	 * @return Returns the Message as a csv compliant line
	 */
	@Override
	public String toString() {
		SimpleDateFormat formatter = new SimpleDateFormat("MMM dd,yyyy HH:mm:ss.SSS");
		
		return this.id + ",\"" + formatter.format(this.timestamp) + "\",\"" + this.loglevel
				+ "\",\"" + this.computer.replaceAll("\"", "\"\"") + "\",\""
				+ this.source.replaceAll("\"", "\"\"") + "\",\""
				+ this.message.replaceAll("\"", "\"\"").replaceAll("\n", " ") + "\"";
	}
}
