package ch.hslu.loggerinterface;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.Properties;

/**
 * Factory which returns a Logger instance
 *
 * @author SWK Interface Group 1 FS 2013
 * @version 1.0
 */
public class LoggerFactory
{
    /**
     * returns a Logger instance from the settings defined in logger.properties
     *
     * @return Logger
     * @throws ClassNotFoundException
     * @throws InstantiationException
     * @throws IllegalAccessException
     * @throws URISyntaxException
     * @throws IOException
     */
	public static Logger getLogger() throws ClassNotFoundException, InstantiationException, IllegalAccessException, IOException, URISyntaxException
	{
        Properties prop = new Properties();
        InputStream in = LoggerFactory.class.getResourceAsStream("/logger.properties");
        prop.load(in);
        in.close();

        File jarFile = new File(LoggerFactory.class.getResource("/" + prop.getProperty("logger_jar")).toURI());

        URL[] url = new URL[1];
        url[0] = jarFile.toURI().toURL();
        URLClassLoader classLoader = new URLClassLoader(url, LoggerFactory.class.getClassLoader());
        Thread.currentThread().setContextClassLoader(classLoader);

        Class loggerClass = Class.forName (prop.getProperty("logger_class"), true, classLoader);
        Logger logger = (Logger)loggerClass.newInstance();

        Class loggerSetupClass = Class.forName(prop.getProperty("logger_setup_class"), true, classLoader);
        LoggerSetup loggerSetup = (LoggerSetup)loggerSetupClass.newInstance();

        loggerSetup.setServer(prop.getProperty("server"));
        loggerSetup.setPort(Integer.parseInt(prop.getProperty("port")));
        loggerSetup.setSource(prop.getProperty("source"));

        logger.setSetup(loggerSetup);

        return logger;
	}

    public static Logger getLogger(String propertiesFilePath) throws ClassNotFoundException, InstantiationException, IllegalAccessException, IOException, URISyntaxException
    {
        Properties prop = new Properties();
        File fd = new File(propertiesFilePath);
        InputStream in = new FileInputStream(fd);
        prop.load(in);
        in.close();

        File jarFile = new File("./" + prop.getProperty("logger_jar"));

        URL[] url = new URL[1];
        url[0] = jarFile.toURI().toURL();
        URLClassLoader classLoader = new URLClassLoader(url, LoggerFactory.class.getClassLoader());
        Thread.currentThread().setContextClassLoader(classLoader);

        Class loggerClass = Class.forName (prop.getProperty("logger_class"), true, classLoader);
        Logger logger = (Logger)loggerClass.newInstance();

        Class loggerSetupClass = Class.forName(prop.getProperty("logger_setup_class"), true, classLoader);
        LoggerSetup loggerSetup = (LoggerSetup)loggerSetupClass.newInstance();

        loggerSetup.setServer(prop.getProperty("server"));
        loggerSetup.setPort(Integer.parseInt(prop.getProperty("port")));
        loggerSetup.setSource(prop.getProperty("source"));

        logger.setSetup(loggerSetup);

        return logger;
    }
}