package ch.hslu.swk.g03.logger.server;

import ch.hslu.corba.loggerinterface.CorbaLogLevel;
import ch.hslu.corba.loggerinterface.CorbaLoggerInterfacePOA;
import ch.hslu.corba.loggerinterface.CorbaLoggerInterfacePackage.CorbaLoggerCouldNotLogException;
import ch.hslu.corba.loggerinterface.CorbaLoggerSetupInterface;
import ch.hslu.loggerinterface.Loglevel;
import ch.hslu.swk.g03.logger.common.LogMessage;

import org.omg.CORBA.BooleanHolder;

/**
 * POA Implementation of the corba logger interface.
 *
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public class ConcreteCorbaLoggerInterfacePOA extends CorbaLoggerInterfacePOA {
    /**
     * The corba logger setup.
     */
    private CorbaLoggerSetupInterface corbaloggersetup;

    /**
     * Constructor.
     */
    public ConcreteCorbaLoggerInterfacePOA() {
	// empty
    }

    /**
     * Sets the corba logger setup.
     *
     * @param clsi
     *            The corba logger setup
     */
    @Override
    public final void setCorbaLoggerSetup(CorbaLoggerSetupInterface clsi) {
	System.err.println("setCorbaLoggerSetup...");
	corbaloggersetup = clsi;
    }

    /**
     * Returns the corba logger setup.
     *
     * @return The corba logger setup.
     */
    @Override
    public final CorbaLoggerSetupInterface getCorbaLoggerSetup() {
	return corbaloggersetup;
    }

    /**
     * Logs a new message.
     *
     * @param cll
     *            The Loglevel to log.
     * @param message
     *            The message to log.
     * @param bh
     *            Booleanholder (true if successfull logged, false if not)
     * @throws CorbaLoggerCouldNotLogException
     */
    @Override
    public final void corbaLog(final CorbaLogLevel cll, final String message, final BooleanHolder bh) throws CorbaLoggerCouldNotLogException {
	System.out.println("Corba! " + message);
	
	try {
	    CorbaLogLevel scll = corbaloggersetup.getCorbaLogLevel();
	    //CorbaLogLevel scll = CorbaLogLevel.DEBUG;

	    if (bh != null) {
		bh.value = false;
	    }

	    if (cll.value() <= scll.value() && cll.value() != 0) {
		Loglevel myLoglevel;
		switch (cll.value()) {

		case CorbaLogLevel._ERROR:
		    myLoglevel = Loglevel.ERROR;
		    break;
		case CorbaLogLevel._WARNING:
		    myLoglevel = Loglevel.WARNING;
		    break;
		case CorbaLogLevel._DEBUG:
		    myLoglevel = Loglevel.DEBUG;
		    break;
		case CorbaLogLevel._INFO:
		    myLoglevel = Loglevel.INFO;
		    break;
		default:
		    myLoglevel = Loglevel.OFF;
		}

		final LogMessage newMessage = new LogMessage(message, myLoglevel, corbaloggersetup.getCorbaLogMessageSource(), "Corba");
		LoggerDB.getInstance().addMessage(newMessage);

		System.out.println("logged!");
		if (bh != null) {
		    bh.value = true;
		}
	    }
	} catch (Exception ex) {
	    System.err.println("Unable to create message from corba interface");
	}
	
    }
}
