package ch.hslu.swk.g03.logger.server;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.util.ArrayList;

import ch.hslu.swk.g03.logger.common.LogMessage;
import ch.hslu.swk.g03.logger.common.ServerRmiInterface;

/**
 * LoggerServer RMI-Server.
 *
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public final class ServerRMI extends UnicastRemoteObject implements ServerRmiInterface {

    private static final long serialVersionUID = 1L;

    /**
     * Default Constructor.
     * @throws RemoteException RMI RemoteException
     */
    public ServerRMI() throws RemoteException {
	super();
	System.out.println("[Info:ServerRMI] init...");
    }

    /**
     * Returns all Messages since Server start.
     * @return ArrayList with all Messages
     */
    @Override
    public ArrayList<LogMessage> getAllMessages() {
	System.out.println("[Info:ServerRMI] getAllMessages()...");
	return LoggerDB.getInstance().getAllMessages();
    }

    /**
     * Returns all new Message since the given ID.
     * @param lastID ID of the latest know Message
     * @return ArrayList with all new Messages since the given ID
     */
    @Override
    public ArrayList<LogMessage> getNewMessages(final int lastID) {
	final int maxMsgID = LoggerDB.getInstance().getMessageCount();
	int validLastID = lastID;
	if (validLastID < 0) {
	    validLastID = 0;
	}
	if (validLastID > maxMsgID) {
	    validLastID = maxMsgID;
	}
	//System.out.println("[Info:ServerRMI] getNewMessages(" + validLastID + ") [MaxID: " + maxMsgID + "]...");
	final ArrayList<LogMessage> tmpList = new ArrayList<LogMessage>(LoggerDB.getInstance().getAllMessages()
		.subList(validLastID, maxMsgID));
	return tmpList;
    }

    /**
     * Get one specific Message.
     * @param index ID of the required Message
     * @return the requested LogMessage
     */
    @Override
    public LogMessage getMessage(final int index) {
	System.out.println("[Info:ServerRMI] getMessage(" + index + ")...");
	if (index > 0 && index <= LoggerDB.getInstance().getMessageCount()) {
	    return LoggerDB.getInstance().getMessage(index - 1);
	} else {
	    return null;
	}
    }

    /**
     * Returns the Number of LogMessages.
     * @return Number of Messages
     */
    @Override
    public int getMessageCount() {
	System.out.println("[Info:ServerRMI] getMessageCount() ==> " + LoggerDB.getInstance().getMessageCount());
	return LoggerDB.getInstance().getMessageCount();
    }
}
